<?php
/**
 * SM FAQ - simple faq component for Joomla! 1.5
 * @version 1.1
 * @package SM FAQ
 * @author SmokerMan
 * @author url http://joomla.forsite.org
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

class SmfaqsModelSmfaq extends JModel
{
	/**
	 * SMFaq id
	 *
	 * @var int
	 */
	var $_id = null;

	/**
	 * SMFaq data
	 *
	 * @var array
	 */
	var $_data = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();

		$id = JRequest::getVar('id', 0, '', 'int');
		$this->setId((int)$id);
		
	}

	function setId($id)
	{
		// Set weblink id and wipe data
		$this->_id		= $id;
		$this->_data	= null;
	}


	function &getData()
	{
		// Load the data
		if ($this->_loadData())
		{
			// access
			$user = &JFactory::getUser();
			if ($user->get('aid', 0) < 2) {
				JError::raiseError( 403, JText::_('ALERTNOTAUTH') );
				return;
			}

			// Check to see if the category is published
			if (!$this->_data->cat_pub) {
				JError::raiseError( 404, JText::_("Resource Not Found") );
				return;
			}

			// Check whether category access level allows access
			if ($this->_data->cat_access > $user->get('aid', 0)) {
				JError::raiseError( 403, JText::_('ALERTNOTAUTH') );
				return;
			}
		}
		else  $this->_initData();
		
		return $this->_data;
	}
	
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadData())
		{
			if ($uid) {
				return ($this->_data->checked_out && $this->_article->checked_out != $uid);
			} else {
				return $this->_data->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'Unable to Load Data');
			return false;
		}
	}


	/**
	 * Method to checkin/unlock 
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$smfaq = & $this->getTable();
			if(! $smfaq->checkin($this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return false;
	}

	/**
	 * Method to checkout/lock the 
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the article out
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the article with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$smfaq = & $this->getTable();
			if(!$smfaq->checkout($uid, $this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}

			return true;
		}
		return false;
	}
	
	function store($data)
	{
		$user = &JFactory::getUser();
		$datenow =& JFactory::getDate();
		
		
		$row =& $this->getTable();
		
		if ($data['id'] < 1) {
			$data['created'] = $datenow->toMySQL();
		} else {
			$config =& JFactory::getConfig();
			$tzoffset = $config->getValue('config.offset');
			$date =& JFactory::getDate($data['created'], $tzoffset);
			$data['created'] = $date->toMySQL();
		}
		if (!$user->guest && $data['id'] < 1) {
			$data['created_by'] = $user->username;
			$data['email'] = $user->email;
			$data['userid'] = $user->id;
		}
		// Bind the form fields to  table
		if (!$row->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// if new item, order last in appropriate group
		if (!$row->id) {
			$where = 'catid = ' . (int) $row->catid ;
			$row->ordering = $row->getNextOrder( $where );
		}
		// Make sure table is valid
		if (!$row->check()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Store table to the database
		if (!$row->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		return true;
	}
	
	function _loadData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$query = 'SELECT w.*, cc.title AS category,' .
					' cc.published AS cat_pub, cc.access AS cat_access'.
					' FROM #__smfaq AS w' .
					' LEFT JOIN #__categories AS cc ON cc.id = w.catid' .
					' WHERE w.id = '. (int) $this->_id;
			$this->_db->setQuery($query);
			$this->_data = $this->_db->loadObject();
			return (boolean) $this->_data;
		}
		return true;
	}
	
	function _initData()
	{
		
		$user = &JFactory::getUser();
		$catid = JRequest::getInt('catid');
		
		$query = 'SELECT c.id, c.access, c.published ' .
		' FROM #__categories AS c' .
		' WHERE c.id = '. (int) $catid .
		' AND c.section = "com_smfaq"';
		$this->_db->setQuery($query);
		$category = $this->_db->loadObject();
		
		if (($category->id < 1) || !$category->published ) {
			JError::raiseError( 404, JText::_("Resource Not Found") );
			return;
		}
		if ($category->access > $user->get('aid', 0)) {
			JError::raiseError( 403, JText::_('ALERTNOTAUTH') );
			return;
		}
		if (empty($this->_data))
		{
			$smfaq = new stdClass();
			$smfaq->id 				= 0;
			$smfaq->catid 			= 0;
			$smfaq->question		= null;
			$smfaq->email			= null;
			$smfaq->created_by		= null;
			$smfaq->send_mail		= null;
			if ($user->get('gid') > 19) {
			$smfaq->published  		= 0;
			$smfaq->state			= 0;
			$smfaq->answer			= null;
			$smfaq->created 		= null;
			$smfaq->ip				= null;
			}
			
			$this->_data			= $smfaq;
			return (boolean) $this->_data;
		}
		return true;
	}

}